<?php 
/**
 * Spangle functions and definitions
 *
 * @package Spangle
 */

// Set the word limit of post content 
function spangle_content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('spangle_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}

function custom_excerpt_length( $length ) { 
	return 30;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );
 

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'spangle_setup' ) ) : 
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function spangle_setup() {
	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'spangle', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support('woocommerce');
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
	add_filter('widget_text', 'do_shortcode');
	add_theme_support( 'title-tag' );
	add_image_size('homepage-thumb',570,380,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'spangle' ),
		'footer' => __( 'Footer Menu', 'spangle' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' ); 
} 
endif; // spangle_setup
add_action( 'after_setup_theme', 'spangle_setup' );


function spangle_widgets_init() { 	 
	
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'spangle' ),
		'description'   => __( 'Appears on blog page sidebar', 'spangle' ),
		'id'            => 'sidebar-1',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
	) );	
	
}
add_action( 'widgets_init', 'spangle_widgets_init' );


function spangle_font_url(){
		$font_url = '';		
		
		/* Translators: If there are any character that are not
		* supported by Montserrat, trsnalate this to off, do not
		* translate into your own language.
		*/
		$montserrat = _x('on','montserrat:on or off','spangle');		
		
		
		/* Translators: If there has any character that are not supported 
		*  by Scada, translate this to off, do not translate
		*  into your own language.
		*/
		$scada = _x('on','Scada:on or off','spangle');	
		
		if('off' !== $montserrat ){
			$font_family = array();
			
			if('off' !== $montserrat){
				$font_family[] = 'Montserrat:300,400,600,700,800,900';
			}
					
						
			$query_args = array(
				'family'	=> urlencode(implode('|',$font_family)),
			);
			
			$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
		}
		
	return $font_url;
	}


function spangle_scripts() {
	wp_enqueue_style('spangle-font', spangle_font_url(), array());
	wp_enqueue_style( 'spangle-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'spangle-editor-style', get_template_directory_uri()."/editor-style.css" );
	wp_enqueue_style( 'nivo-slider', get_template_directory_uri()."/css/nivo-slider.css" );
	wp_enqueue_style( 'spangle-main-style', get_template_directory_uri()."/css/responsive.css" );		
	wp_enqueue_style( 'spangle-base-style', get_template_directory_uri()."/css/style_base.css" );
	wp_enqueue_script( 'jquery-nivo', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'spangle-custom-js', get_template_directory_uri() . '/js/custom.js' );	
	wp_enqueue_style( 'spangle-font-awesome-style', get_template_directory_uri()."/css/font-awesome.css" );
		

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'spangle_scripts' );

function spangle_ie_stylesheet(){
	global $wp_styles;
	
	/** Load our IE-only stylesheet for all versions of IE.
	*   <!--[if lt IE 9]> ... <![endif]-->
	*
	*  Note: It is also possible to just check and see if the $is_IE global in WordPress is set to true before
	*  calling the wp_enqueue_style() function. If you are trying to load a stylesheet for all browsers
	*  EXCEPT for IE, then you would HAVE to check the $is_IE global since WordPress doesn't have a way to
	*  properly handle non-IE conditional comments.
	*/
	wp_enqueue_style('spangle_ie', get_template_directory_uri().'/css/ie.css', array('spangle_style'));
	$wp_styles->add_data('spangle_ie','conditional','IE');
	}
add_action('wp_enqueue_scripts','spangle_ie_stylesheet');


define('Grace_URL','http://www.gracethemes.com/','spangle');
define('Grace_PRO_THEME_URL','http://gracethemes.com/themes/construction-wordpress-theme/','spangle');
define('Grace_THEME_DOC','http://www.gracethemes.com/documentation/creation-doc/','spangle');
define('Grace_LIVE_DEMO','http://gracethemes.com/demo/creation/','spangle');
define('Grace_THEMES','http://www.gracethemes.com/themes/','spangle');

function spangle_designbytext(){
		return "Design by <a href=".esc_url(Grace_URL)." target='_blank'>Grace Themes</a>";
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template for about theme.
 */
require get_template_directory() . '/inc/about-themes.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


// get slug by id
function spangle_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}